==> haskell-data-serializer-0.3.5-19-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-data-serializer.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 data-serializer
version:              0.3.5
visibility:           public
id:                   data-serializer-0.3.5-JzrtDf5XkY2DtNXanbdg2T
key:                  data-serializer-0.3.5-JzrtDf5XkY2DtNXanbdg2T
license:              BSD-3-Clause
copyright:            2016 Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
maintainer:           Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
author:               Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
stability:            experimental
homepage:             https://github.com/mvv/data-serializer
synopsis:             Common API for serialization libraries
description:
    This package provides a common API for serialization libraries like
    <http://hackage.haskell.org/package/binary binary> and
    <http://hackage.haskell.org/package/cereal cereal>.

category:             Data
abi:                  c801f72b37b0014f4ce6570fac89eaf1
exposed:              True
exposed-modules:      Data.Deserializer Data.Serializer
import-dirs:          /usr/lib/ghc-9.0.1/site-local/data-serializer-0.3.5
library-dirs:         /usr/lib/ghc-9.0.1/site-local/data-serializer-0.3.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/data-serializer-0.3.5
hs-libraries:         HSdata-serializer-0.3.5-JzrtDf5XkY2DtNXanbdg2T
depends:
    base-4.15.0.0 binary-0.8.8.0 bytestring-0.10.12.1
    cereal-0.5.8.1-8mCXAg3ZUhz3qnQL3xR8hS
    data-endian-0.1.1-HDsZkSHCE8T7o4T3ea9gTc
    parsers-0.12.10-Hi3O79Zj02HIwov9FVSfsr
    split-0.2.3.4-3GPEtI7FHlo9LLbmFb1MgX

haddock-interfaces:
    /usr/share/doc/haskell-data-serializer/html/data-serializer.haddock

haddock-html:         /usr/share/doc/haskell-data-serializer/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-data-serializer-0.3.5-20-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-data-serializer.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 data-serializer
version:              0.3.5
visibility:           public
id:                   data-serializer-0.3.5-7MbjkyYjZGwFskv1lsjgyp
key:                  data-serializer-0.3.5-7MbjkyYjZGwFskv1lsjgyp
license:              BSD-3-Clause
copyright:            2016 Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
maintainer:           Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
author:               Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
stability:            experimental
homepage:             https://github.com/mvv/data-serializer
synopsis:             Common API for serialization libraries
description:
    This package provides a common API for serialization libraries like
    <http://hackage.haskell.org/package/binary binary> and
    <http://hackage.haskell.org/package/cereal cereal>.

category:             Data
abi:                  d47025c344fbfd0e81d3f6cc9833ceac
exposed:              True
exposed-modules:      Data.Deserializer Data.Serializer
import-dirs:          /usr/lib/ghc-9.0.1/site-local/data-serializer-0.3.5
library-dirs:         /usr/lib/ghc-9.0.1/site-local/data-serializer-0.3.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/data-serializer-0.3.5
hs-libraries:         HSdata-serializer-0.3.5-7MbjkyYjZGwFskv1lsjgyp
depends:
    base-4.15.0.0 binary-0.8.8.0 bytestring-0.10.12.1
    cereal-0.5.8.1-8mCXAg3ZUhz3qnQL3xR8hS
    data-endian-0.1.1-HDsZkSHCE8T7o4T3ea9gTc
    parsers-0.12.10-KQHeLX32Hya7x4C3PMKSbZ
    split-0.2.3.4-5j6CeOPTiEKf5SlYOEzg5

haddock-interfaces:
    /usr/share/doc/haskell-data-serializer/html/data-serializer.haddock

haddock-html:         /usr/share/doc/haskell-data-serializer/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
